@@ -205,17 +205,6 @@ var (
 		Datasource: "string",
 	}
 
-	basicMockBuilder = &MockBuilder{
-		Config: MockConfig{
-			NestedMockConfig: builderBasicNestedMockConfig,
-			Nested:           builderBasicNestedMockConfig,
-			NestedSlice: []NestedMockConfig{
-				builderBasicNestedMockConfig,
-				builderBasicNestedMockConfig,
-			},
-		},
-	}
-
 	basicMockProvisioner = &MockProvisioner{
 		Config: MockConfig{
 			NotSquashed:      "value <UNKNOWN>",
@@ -273,17 +262,6 @@ var (
 			NestedSlice: []NestedMockConfig{},
 		},
 	}
-	basicMockCommunicator = &MockCommunicator{
-		Config: MockConfig{
-			NestedMockConfig: basicNestedMockConfig,
-			Nested:           basicNestedMockConfig,
-			NestedSlice: []NestedMockConfig{
-				{
-					Tags: []MockTag{},
-				},
-			},
-		},
-	}
 
 	emptyMockBuilder = &MockBuilder{
 		Config: MockConfig{
@@ -295,13 +273,6 @@ var (
 		},
 	}
 
-	emptyMockProvisioner = &MockProvisioner{
-		Config: MockConfig{
-			NestedMockConfig: NestedMockConfig{Tags: []MockTag{}},
-			NestedSlice:      []NestedMockConfig{},
-		},
-	}
-
 	dynamicTagList = []MockTag{
 		{
 			Key:   "first_tag_key",
