@@ -5,6 +5,7 @@ package hcl2template
 
 import (
 	"fmt"
+	"regexp"
 
 	"github.com/hashicorp/hcl/v2"
 	"github.com/hashicorp/hcl/v2/gohcl"
@@ -23,6 +24,8 @@ type HCPPackerRegistryBlock struct {
 	HCL2Ref
 }
 
+var bucketNameRegexp = regexp.MustCompile("^[a-zA-Z0-9-]{3,36}$")
+
 func (p *Parser) decodeHCPRegistry(block *hcl.Block, cfg *PackerConfig) (*HCPPackerRegistryBlock, hcl.Diagnostics) {
 	par := &HCPPackerRegistryBlock{}
 	body := block.Body
@@ -51,6 +54,14 @@ func (p *Parser) decodeHCPRegistry(block *hcl.Block, cfg *PackerConfig) (*HCPPac
 		return nil, diags
 	}
 
+	if !bucketNameRegexp.MatchString(b.Slug) {
+		diags = diags.Append(&hcl.Diagnostic{
+			Severity: hcl.DiagError,
+			Summary:  fmt.Sprintf("%s.bucket_name can only contain between 3 and 36 ASCII letters, numbers and hyphens", buildHCPPackerRegistryLabel),
+			Subject:  block.DefRange.Ptr(),
+		})
+	}
+
 	par.Slug = b.Slug
 	par.Description = b.Description
 
